@@ -1,7 +1,7 @@
 #' truncate message parts
-#'
+#' 
 #' truncate long vectors for messages
-#'
+#' 
 #' @return Character string
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Nov 2016
 #' @seealso \code{\link{message}}
@@ -20,19 +20,21 @@
 #' @param ntrunc Integer: number of elements printed before truncation. DEFAULT: 3
 #' @param prefix Character: Prefix added if \code{length(x)>1}. DEFAULT: "s"
 #' @param midfix Character: string added after prefix OR before first altnix. DEFAULT: " "
-#' @param altnix Character: Alternative string padded around x if \code{length(x)==1}. 
+#' @param altnix Character: Alternative string padded around x if \code{length(x)==1}.
 #'               DEFAULT: "'"
-#'
+#' @param sep    Character: Separator between elements. DEFAULT: ", "
+#' 
 truncMessage <- function(
 x,
 ntrunc=3,
 prefix="s",
 midfix=" ",
-altnix="'"
+altnix="'",
+sep=", "
 )
 {
 l <- length(x)
 if(l>ntrunc) x <- x[1:ntrunc]
-paste0(if(l>1) paste0(prefix,midfix) else paste0(midfix,altnix), toString(x), 
-       if(l>ntrunc) paste(" (and",l-ntrunc,"more)"), if(l==1) altnix)
+paste0(if(l>1) paste0(prefix,midfix) else paste0(midfix,altnix), paste0(x, collapse=sep),
+       if(l>ntrunc) paste(if(!missing(sep)) sep, " (and",l-ntrunc,"more)"), if(l==1) altnix)
 }
